/***********************************************************
 * Hajime no Ippo --- file : hjime.cpp
 ***********************************************************/
#include <ode/ode.h>
#include <drawstuff/drawstuff.h>

static dWorldID world; // 世界ID
static dBodyID box;    // 剛体ID
dReal  box_sizes[3] = { 1.0, 1.0, 1.0 };
                       // 剛体のサイズ

#ifdef dDOUBLE
  #define dsDrawBox dsDrawBoxD
#endif

// start simulation - set viewpoint
static void start()
{
  static float xyz[3] = { 0.f, 5.f, 3.f };
  static float hpr[3] = { -90.f, -15.f, 0.f };

  dsSetViewpoint( xyz, hpr ); // カメラ位置と方向設定
}

// simulation loop
static void simLoop( int pause )
{
    // Ctl+p が押されたらifに入らない
    if (!pause)
    {
        dWorldStep( world, 0.01 ); // 世界を進める
    }

    // 剛体の表示
    dsSetColor( 1.0f, 1.0f, 0.0f ); // RGB Color
    dsDrawBox( dBodyGetPosition( box ),
            dBodyGetRotation( box ),
            box_sizes );
}


int main( int argc, char* argv[] )
{
    dInitODE();

    // setup pointers to drawstuff callback functions
    dsFunctions fn;
    fn.version = DS_VERSION;
    fn.start   = &start;
    fn.step    = &simLoop;
    fn.command = 0;
    fn.stop    = 0;
    fn.path_to_textures = "../drawstuff/textures";

    world = dWorldCreate();         // 世界生成
    //dWorldSetGravity( world, 0.0, 0.0, -9.8 );
    // 世界に重力を生成(z方向に-9.8m/s/s)

  box = dBodyCreate( world );     // 世界に剛体を作成
  dReal pos[3] = { 0.0, 0.0, 3.0 };
  dBodySetPosition( box, pos[0], pos[1], pos[2] );
                                  // 剛体の位置を設定

  dsSimulationLoop( argc, argv, 320, 240, &fn );
                                  // シミュレーション開始(simLoopへ)
                                  // + ウィンドウサイズ設定

  dWorldDestroy( world );         // 世界の破壊
  return 0;
}

